Changelog
=========

1.0b2 (2024-06-27)
------------------

- Conservative encoding for the filename
  [ebrehault]


1.0b1 (2024-05-24)
------------------

- Allow to re-index all files
  [ebrehault]

- Support different field name for the file content, and allow to map metadata fields
  [ebrehault]

- Compliancy with Plone 5.1
  [ebrehault]

- Allow to re-index all files
  [ebrehault]


1.0a3 (2022-10-10)
------------------

- Fix project metadata.
  [ebrehault]

1.0a2 (2022-10-03)
------------------

- Fix project metadata.
  [ebrehault]


1.0a1 (2022-10-03)
------------------

- Initial release.
  [ebrehault]
